#!/usr/bin/env python

"""
List of APIs supported by Gurunudi
"""
API_CHAT		='chatbot' #real time conversation and knowledge q&a - ideal for chatbots

"""
Fields returned in response JSON by Gurunudi API calls and Fields sent in request JSON to Gurunudi API calls
"""
FIELD_LANG='lang'
FIELD_TARGET_LANG='target'
FIELD_CONTEXT='context'
FIELD_TEXT="text"
FIELD_ERROR="error"
FIELD_LIST="list"
FIELD_MODEL="model"

ERROR_SERVER_INACCESSIBLE="server_inaccessible"
ERROR_INVALID_LANGUAGE_CODE="invalid_language_code" 
ERROR_NO_RESPONSE="no_response_for_api"




#!/usr/bin/env python


"""
Gurunudi Language codes for different languages
"""

ABKHAZIAN ="abk"
AFAR ="aar"
AFRIKAANS ="afr"
AHOM ="aho"
ALBANIAN ="sqi"
ARABIC ="ara"
ARMENIAN ="hye"
AZERBAIJANI ="aze"
BALINESE ="ban"
BAMUM ="bax"
BASQUE ="eus"
BASSA ="bsq"
BATAK ="btk"
BELARUSIAN ="bel"
BENGALI ="ben"
BOSNIAN ="bos"
BUGINESE ="bug"
BUHID ="bku"
BULGARIAN ="bul"
BURMESE ="mya"
MYANMAR ="mya"
CATALAN ="cat"
CEBUANO ="ceb"
CENTRAL_KHMER ="khm"
CAMBODIAN ="khm"
CHAKMA ="ccp"
CHINESE ="zho"
CORSICAN ="cos"
CROATIAN ="hrv"
CZECH ="ces"
DANISH ="dan"
DUTCH ="nld"
ENGLISH ="eng"
ESPERANTO ="epo"
ESTONIAN ="est"
FILIPINO ="fil"
FINNISH ="fin"
FRENCH ="fra"
FULA ="ful"
GALICIAN ="glg"
GEORGIAN ="kat"
GERMAN ="deu"
GOAN_KONKANI ="gom"
GREEK ="ell"
GUJARATI ="guj"
HAITIAN ="hat"
HANUNOO ="hnn"
HAUSA ="hau"
HAWAIIAN ="haw"
HEBREW ="heb"
HINDI ="hin"
HMONG ="hmn"
HUNGARIAN ="hun"
ICELANDIC ="isl"
IGBO ="ibo"
INDONESIAN ="ind"
IRISH ="gle"
ITALIAN ="ita"
JAPANESE ="jpn"
JAVANESE ="jav"
KANNADA ="kan"
KAZAKH ="kaz"
KONKANI ="kok"
KOREAN ="kor"
KURDISH ="kur"
LAO ="lao"
LATIN ="lat"
LATVIAN ="lav"
LEPTCHA ="lep"
LIMBU ="lif"
LISU ="lis"
LITHUANIAN ="lit"
MACEDONIAN ="mkd"
MAITHILI ="mai"
MALAGASY ="mlg"
MALAY ="msa"
MALAYALAM ="mal"
MALTESE ="mlt"
MANDARIN_CHINESE ="cmn"
MAORI ="mri"
MARATHI ="mar"
MENDE ="men"
MONGOLIAN ="mon"
MRU ="mro"
NEPALI ="nep"
NORTH_TAIRORA ="tbg"
NORWEGIAN ="nor"
NORWEGIAN_BOKMAL ="nob"
NORWEGIAN_NYNORSK ="nno"
NYANJA ="nya"
ODIA ="ori"
ORIYA ="ori"
PERSIAN ="fas"
POLISH ="pol"
PORTUGUESE ="por"
PRAKRIT ="pra"
PUNJABI ="pan"
PUSHTO ="pus"
ROMANIAN ="ron"
RUSSIAN ="rus"
SANSKRIT ="san"
SANTALI ="sat"
SARAIKI ="skr"
MULTANI ="skr"
SAURASHTRA ="saz"
SERBIAN ="srp"
SINHALA ="sin"
SLOVAK ="slk"
SLOVENIAN ="slv"
SOMALI ="som"
SORA ="srb"
SOUTH_TAIRORA ="omw"
SOUTHERN_SOTHO ="sot"
SPANISH ="spa"
SUNDANESE ="sun"
SWAHILI ="swa"
SWEDISH ="swe"
TAGALOG ="tgl"
TAI_NUA ="tdd"
TAJIK ="tgk"
TAMIL ="tam"
TANGUT ="txg"
TELUGU ="tel"
THAI ="tha"
TULU ="tcy"
TURKISH ="tur"
UKRAINIAN ="ukr"
URDU ="urd"
UZBEK ="uzb"
VAI ="vai"
VIETNAMESE ="vie"
WELSH ="cym"
WESTERN_FRISIAN ="fry"
YIDDISH ="yid"
YORUBA ="yor"
ZULU ="zul"


names={'abk': 'Abkhazian', 'aar': 'Afar', 'afr': 'Afrikaans', 'aho': 'Ahom', 'sqi': 'Albanian', 'ara': 'Arabic', 'hye': 'Armenian', 'aze': 'Azerbaijani', 'ban': 'Balinese', 'bax': 'Bamum', 'eus': 'Basque', 'bsq': 'Bassa', 'btk': 'Batak', 'bel': 'Belarusian', 'ben': 'Bengali', 'bos': 'Bosnian', 'bug': 'Buginese', 'bku': 'Buhid', 'bul': 'Bulgarian', 'mya': 'Burmese', 'cat': 'Catalan', 'ceb': 'Cebuano', 'khm': 'Central Khmer', 'ccp': 'Chakma', 'zho': 'Chinese', 'cos': 'Corsican', 'hrv': 'Croatian', 'ces': 'Czech', 'dan': 'Danish', 'nld': 'Dutch', 'eng': 'English', 'epo': 'Esperanto', 'est': 'Estonian', 'fil': 'Filipino', 'fin': 'Finnish', 'fra': 'French', 'ful': 'Fula', 'glg': 'Galician', 'kat': 'Georgian', 'deu': 'German', 'gom': 'Goan Konkani', 'ell': 'Greek', 'guj': 'Gujarati', 'hat': 'Haitian', 'hnn': 'Hanunoo', 'hau': 'Hausa', 'haw': 'Hawaiian', 'heb': 'Hebrew', 'hin': 'Hindi', 'hmn': 'Hmong', 'hun': 'Hungarian', 'isl': 'Icelandic', 'ibo': 'Igbo', 'ind': 'Indonesian', 'gle': 'Irish', 'ita': 'Italian', 'jpn': 'Japanese', 'jav': 'Javanese', 'kan': 'Kannada', 'kaz': 'Kazakh', 'kok': 'Konkani', 'kor': 'Korean', 'kur': 'Kurdish', 'lao': 'Lao', 'lat': 'Latin', 'lav': 'Latvian', 'lep': 'Leptcha', 'lif': 'Limbu', 'lis': 'Lisu', 'lit': 'Lithuanian', 'mkd': 'Macedonian', 'mai': 'Maithili', 'mlg': 'Malagasy', 'msa': 'Malay', 'mal': 'Malayalam', 'mlt': 'Maltese', 'cmn': 'Mandarin Chinese', 'mri': 'Maori', 'mar': 'Marathi', 'men': 'Mende', 'mon': 'Mongolian', 'mro': 'Mru', 'nep': 'Nepali', 'tbg': 'North Tairora', 'nor': 'Norwegian', 'nob': 'Norwegian Bokmal', 'nno': 'Norwegian Nynorsk', 'nya': 'Nyanja', 'ori': 'Oriya', 'fas': 'Persian', 'pol': 'Polish', 'por': 'Portuguese', 'pra': 'Prakrit', 'pan': 'Punjabi', 'pus': 'Pushto', 'ron': 'Romanian', 'rus': 'Russian', 'san': 'Sanskrit', 'sat': 'Santali', 'skr': 'Saraiki', 'saz': 'Saurashtra', 'srp': 'Serbian', 'sin': 'Sinhala', 'slk': 'Slovak', 'slv': 'Slovenian', 'som': 'Somali', 'srb': 'Sora', 'omw': 'South Tairora', 'sot': 'Southern Sotho', 'spa': 'Spanish', 'sun': 'Sundanese', 'swa': 'Swahili', 'swe': 'Swedish', 'tgl': 'Tagalog', 'tdd': 'Tai Nua', 'tgk': 'Tajik', 'tam': 'Tamil', 'txg': 'Tangut', 'tel': 'Telugu', 'tha': 'Thai', 'tcy': 'Tulu', 'tur': 'Turkish', 'ukr': 'Ukrainian', 'urd': 'Urdu', 'uzb': 'Uzbek', 'vai': 'Vai', 'vie': 'Vietnamese', 'cym': 'Welsh', 'fry': 'Western Frisian', 'yid': 'Yiddish', 'yor': 'Yoruba', 'zul': 'Zulu'}



#!/usr/bin/env python

from setuptools import setup, PEP420PackageFinder

pep420_package_finder = PEP420PackageFinder()
readme=open('README.rst',encoding='utf8').read()

setup(name='gurunudi',
      version='2.0.3',	
      description='The official Python client for Gurunudi AI API',
      long_description=readme,
      url='http://github.com/guruyuga/gurunudi',
      author='GuruYuga',
      author_email='contact@gurunudi.com',
      license='Apache-2.0',
      packages=pep420_package_finder.find('.', include=['gurunudi*']),
      keywords=["guruyuga","gurunudi","artificial-intelligence","chatbot","nlp","nlg","nli","machine-learning","sentiment-analysis","natural-language-processing","natural-language-generation","natural-language-inference","machine-translation","autocomplete","autocorrect","spell-check","coreference-resolution","knowledge-graph","expert-system","context-qa","topic-modeling"],
      install_requires=['requests>=2.13.0'],
      classifiers=[
                'Development Status :: 4 - Beta',
                'Environment :: Console',
                'Intended Audience :: Developers',
                'Intended Audience :: Science/Research',
                'License :: OSI Approved :: MIT License',
                'Operating System :: POSIX :: Linux',
                'Operating System :: MacOS :: MacOS X',
                'Operating System :: Microsoft :: Windows',
                'Programming Language :: Python :: 2',
                'Programming Language :: Python :: 2.7',
                'Programming Language :: Python :: 3',
                'Programming Language :: Python :: 3.4',
                'Programming Language :: Python :: 3.5',
                'Programming Language :: Python :: 3.6',
'Topic :: Scientific/Engineering :: Artificial Intelligence'],)



#!/usr/bin/env python

"""Generic URI of the Gurunudi AI API"""
API_URL = "https://api.gurunudi.com/{}/{}"	

"""Gurunudi AI API accepts and sents JSON content only"""
HEADERS = {'Content-type': 'application/json; charset=utf-8', 'Accept': 'application/json','User-Agent':'Gurunudi Python Client 2.0.3','gnapi':'demo'}

DEBUG = False



#!/usr/bin/env python

from __future__ import division, print_function, absolute_import

import requests
from . import constants
from . import lang
from . import config
import sys

class AI(object):
	"""
	Python class wrapper for Gurunudi AI methods - uses POST method, but GET is also supported by server for testing purposes or quick usage.
	"""


	def __init__(self,api_key=None,version=1):
		"""
		version (int): The API version to be used while querying Gurunudi Server
		api_key (string): The API key to access the Gurunudi platform

		"""
		self.version='v'+str(version)
		
		if api_key:
			config.HEADERS['gnapi']=api_key

	def chat(self,text,language=lang.ENGLISH):
		"""
		text (string): The text to be responded to
		language (string): ISO3 language code of the text
		returns: chat response to the text - ideal for chatbots
		"""
		if language==lang.ENGLISH:
			return self.__call_api(constants.API_CHAT,'{0}={1}'.format(constants.FIELD_TEXT,text))
		else: 			
			return self.__call_api(constants.API_CHAT,'{0}={1}&{2}={3}'.format(constants.FIELD_TEXT,text,constants.FIELD_LANG,language))


	def __call_api(self,api,data):
		"""
		calls given Gurunudi api with given data and returns the result
		api (string): The name of the API to call
		data (string): Data to be sent to the API
		"""


		try:
			if config.DEBUG:
				print("Call API",api)
				print("Request Data",data)

			#call the API
			url = config.API_URL.format(self.version,api)
			response = requests.get('{0}?{1}'.format(url,data), headers=config.HEADERS)
			json=response.json()

			if config.DEBUG:
				print("Request URI",url)
				print("Request data",data)
				print("Response Code",response.status_code)
				print("Response data",json)
				
			if response.status_code==200:#if response OK
				return json
			else:
				raise APIError("status_code_"+str(response.status_code))

		except requests.exceptions.ConnectionError as ex:
			print(ex,file=sys.stderr)
			raise APIError(constants.ERROR_SERVER_INACCESSIBLE)

class APIError(Exception):
	def __init__(self, message):
		super(APIError,self).__init__(message)


